==> dif-content-manager-db-2.1.5-18-sources.jar: pt/digitalis/dif/content/model/data/ContentItemAcl.java <==
package pt.digitalis.dif.content.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * ContentItemAcl
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class ContentItemAcl extends AbstractBeanAttributes implements java.io.Serializable {

    /** ContentItemAcl attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";
        /** groupId column */
        public static final String GROUPID = "groupId";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");

            return list;
        }
    }

    /** ContentItemAcl FK class */
    public static class FK {
        /** contentItem relation */
        public static final String CONTENTITEM = "contentItem";
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("contentItem".equalsIgnoreCase(attributeName))
            return contentItem;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("contentItem".equalsIgnoreCase(attributeName))
            contentItem = (ContentItem)attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String)attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** contentItem private attribute */
    private ContentItem contentItem;

    /** userId private attribute */
    private String userId;

    /** groupId private attribute */
    private String groupId;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ContentItemAcl() {
    }

	/** 
	 * minimal constructor
	 *
     * @param contentItem
    }
	 */
    public ContentItemAcl(ContentItem contentItem) {
        this.contentItem = contentItem;
    }

    /**
     * full constructor
	 *
     * @param contentItem
     * @param userId
     * @param groupId
     */
    public ContentItemAcl(ContentItem contentItem, String userId, String groupId) {
        this.contentItem = contentItem;
        this.userId = userId;
        this.groupId = groupId;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * contentItem getter method
     *
     * @return contentItem method
     */
    public ContentItem getContentItem() {
        return this.contentItem;
    }
    
    /**       
     * contentItem setter method
     *
     * @param contentItem
     *
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setContentItem(ContentItem contentItem) {
        this.contentItem = contentItem;
        
        return this;
    }
    /**       
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId() {
        return this.userId;
    }
    
    /**       
     * userId setter method
     *
     * @param userId
     *
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setUserId(String userId) {
        this.userId = userId;
        
        return this;
    }
    /**       
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId() {
        return this.groupId;
    }
    
    /**       
     * groupId setter method
     *
     * @param groupId
     *
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setGroupId(String groupId) {
        this.groupId = groupId;
        
        return this;
    }

    /**
     * Creates a String representation of the ContentItemAcl object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("userId").append("='").append(getUserId()).append("' ");			
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ContentItemAcl object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ContentItemAcl other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
        	this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
        	this.groupId = attributeValue;

    }


}

==> dif-content-manager-db-2.2.0-2-sources.jar: pt/digitalis/dif/content/model/data/ContentItemAcl.java <==
package pt.digitalis.dif.content.model.data;

import java.util.ArrayList;
import java.util.List;

import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * ContentItemAcl Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class ContentItemAcl extends AbstractBeanAttributes implements java.io.Serializable {

    /** ContentItemAcl attributes enumeration */
    public static class Fields {

        /** groupId column */
        public static final String GROUPID = "groupId";
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");

            return list;
        }
    }

    /** ContentItemAcl FK class */
    public static class FK {

        /** contentItem relation */
        public static final String CONTENTITEM = "contentItem";
    }

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    // Fields

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /** contentItem private attribute */
    private ContentItem contentItem;

    /** groupId private attribute */
    private String groupId;

    /** id private attribute */
    private Long id;

    /** userId private attribute */
    private String userId;

    /**
     * default constructor
     */
    public ContentItemAcl()
    {}

    /**
     * minimal constructor
     *
     * @param contentItem
     *            }
     */
    public ContentItemAcl(ContentItem contentItem)
    {
        this.contentItem = contentItem;
    }

    /**
     * full constructor
     *
     * @param contentItem
     * @param userId
     * @param groupId
     */
    public ContentItemAcl(ContentItem contentItem, String userId, String groupId)
    {
        this.contentItem = contentItem;
        this.userId = userId;
        this.groupId = groupId;
    }

    // Constructors

    /**
     * Compares the String representation of the ContentItemAcl object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(ContentItemAcl other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("contentItem".equalsIgnoreCase(attributeName))
            return contentItem;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;

        return null;
    }

    // Property accessors

    /**
     * contentItem getter method
     *
     * @return contentItem method
     */
    public ContentItem getContentItem()
    {
        return this.contentItem;
    }

    /**
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId()
    {
        return this.groupId;
    }

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId()
    {
        return this.userId;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("contentItem".equalsIgnoreCase(attributeName))
            contentItem = (ContentItem) attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String) attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String) attributeValue;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
            this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
            this.groupId = attributeValue;

    }

    /**
     * contentItem setter method
     *
     * @param contentItem
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setContentItem(ContentItem contentItem)
    {
        this.contentItem = contentItem;

        return this;
    }

    /**
     * groupId setter method
     *
     * @param groupId
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setGroupId(String groupId)
    {
        this.groupId = groupId;

        return this;
    }

    /**
     * id setter method
     *
     * @param id
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * userId setter method
     *
     * @param userId
     * @return ContentItemAcl modified instance
     */
    public ContentItemAcl setUserId(String userId)
    {
        this.userId = userId;

        return this;
    }

    /**
     * Creates a String representation of the ContentItemAcl object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("userId").append("='").append(getUserId()).append("' ");
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

}
